@@ -41,12 +41,24 @@ class Client:
         self.session = requests.Session()
         self._test_endpoint()
 
-    def project(self, project_id, path=".", force_download=False, annotations_only=False):
+    def project(
+        self,
+        project_id,
+        dataset_id=None,
+        path=".",
+        force_download=False,
+        annotations_only=False,
+        label_group_num=None,
+    ):
         """Initializes Project class given project id.
 
         Arguments:
-            project_id: hash ID of project.
-            path: directory used for data.
+            project_id: hash ID of project
+            dataset_id: hash ID of dataset (optional - default `None`)
+            path: directory used for data (optional - default `"."`)
+            force_download: if `True`, ignores possible existing data in `path` (optional - default `False`)
+            annotations_only: if `True`, downloads annotations only (optional - default `False`)
+            label_group_num: number for the label group to download (optional - default `None`)
         """
         if path == ".":
             print("Using working directory for data.")
@@ -57,10 +69,12 @@ class Client:
         data_manager_kwargs = {
             "domain": self.domain,
             "project_id": project_id,
+            "dataset_id": dataset_id,
             "path": path,
             "session": self.session,
             "headers": self._create_headers(),
             "force_download": force_download,
+            "label_group_num": label_group_num,
         }
 
         annotations_data_manager = ProjectDataManager("annotations", **data_manager_kwargs)
@@ -81,6 +95,40 @@ class Client:
             print("No project created. Downloaded annotations only.")
             return None
 
+    def download_model_outputs(
+        self, project_id, dataset_id=None, model_id=None, path=".", force_download=False
+    ):
+        """Downloads model outputs given project_id.
+
+        Arguments:
+            project_id: hash ID of project
+            dataset_id: hash ID of dataset (optional - default `None`)
+            model_id: hash ID of the model (optional - default `None`)
+            path: directory used for data (optional - default `"."`)
+            force_download: if `True`, ignores possible existing data in `path` (optional - default `False`)
+        """
+        if path == ".":
+            print("Using working directory for model outputs.")
+        else:
+            os.makedirs(path, exist_ok=True)
+            print(f"Using path '{path}' for data.")
+
+        data_manager_kwargs = {
+            "domain": self.domain,
+            "project_id": project_id,
+            "dataset_id": dataset_id,
+            "model_id": model_id,
+            "path": path,
+            "session": self.session,
+            "headers": self._create_headers(),
+            "force_download": force_download,
+        }
+
+        model_outputs_manager = ProjectDataManager("model-outputs", **data_manager_kwargs)
+        model_outputs_manager.create_data_export_job()
+        model_outputs_manager.wait_until_ready()
+        return None
+
     def load_model_annotations(self):
         """Deprecated method: use `import_annotations` instead.
         """
@@ -100,11 +148,11 @@ class Client:
             chunk_size: number of annotations to load as a chunk.
         """
         if not annotations:
-            print(f"No annotations provided.")
+            print("No annotations provided.")
         if not project_id:
-            print(f"project_id is required.")
+            print("project_id is required.")
         if not dataset_id:
-            print(f"dataset_id is required.")
+            print("dataset_id is required.")
 
         num_chunks = math.ceil(len(annotations) / chunk_size)
 
@@ -199,13 +247,16 @@ class ProjectDataManager:
         data_type,
         domain=None,
         project_id=None,
+        dataset_id=None,
+        label_group_num=None,
+        model_id=None,
         path=".",
         session=None,
         headers=None,
         force_download=False,
     ):
-        if data_type not in ["images", "annotations"]:
-            raise ValueError("data_type must be 'images' or 'annotations'.")
+        if data_type not in ["images", "annotations", "model-outputs"]:
+            raise ValueError("data_type must be 'images' or 'annotations' or 'model-outputs'.")
         if not domain:
             raise ValueError("domain is not specified.")
         if not project_id:
@@ -218,6 +269,9 @@ class ProjectDataManager:
 
         self.domain = domain
         self.project_id = project_id
+        self.dataset_id = dataset_id
+        self.label_group_num = label_group_num
+        self.model_id = model_id
         self.path = path
         if session and isinstance(session, requests.Session):
             self.session = session
@@ -255,12 +309,24 @@ class ProjectDataManager:
 
     def _get_data_export_params(self):
         if self.data_type == "images":
-            params = {"projectHashId": self.project_id, "exportFormat": "zip"}
+            params = {
+                "projectHashId": self.project_id,
+                "datasetHashId": self.dataset_id,
+                "exportFormat": "zip",
+            }
         elif self.data_type == "annotations":
             # TODO: restrict to assigned labelgroup
             params = {
                 "projectHashId": self.project_id,
-                "labelGroupNum": None,
+                "datasetHashId": self.dataset_id,
+                "labelGroupNum": self.label_group_num,
+                "exportFormat": "json",
+            }
+        elif self.data_type == "model-outputs":
+            params = {
+                "projectHashId": self.project_id,
+                "datasetHashId": self.dataset_id,
+                "modelHashId": self.model_id,
                 "exportFormat": "json",
             }
         return params
@@ -287,7 +353,13 @@ class ProjectDataManager:
             self._on_data_export_job_error()
             return
 
-        if status == "running":
+        if status == "done":
+            self._on_data_export_job_done()
+
+        elif status == "error":
+            self._on_data_export_job_error()
+
+        elif status == "running":
             try:
                 progress = int(body["progress"])
             except (TypeError, ValueError):
@@ -298,32 +370,24 @@ class ProjectDataManager:
                 time_remaining = 0
 
             # print formatted progress info
-            if progress > 0 and progress <= 100 and time_remaining > 0:
-                if time_remaining > 45:
-                    time_remaining_fmt = (
-                        arrow.now().shift(seconds=time_remaining).humanize(only_distance=True)
-                    )
-                else:
-                    # arrow humanizes <= 45 to 'in seconds' or 'just now',
-                    # so we will opt to be explicit instead.
-                    time_remaining_fmt = f"in {time_remaining} seconds"
-                end_char = "\r" if progress < 100 else "\n"
-                msg = (
-                    f"Exporting {self.data_type} for project {self.project_id}..."
-                    + f"{progress}% (time remaining: {time_remaining_fmt})."
+            if time_remaining > 45:
+                time_remaining_fmt = (
+                    arrow.now().shift(seconds=time_remaining).humanize(only_distance=True)
                 )
-                print(msg.ljust(100), end=end_char, flush=True)
+            else:
+                # arrow humanizes <= 45 to 'in seconds' or 'just now',
+                # so we will opt to be explicit instead.
+                time_remaining_fmt = f"{time_remaining} seconds"
+            end_char = "\r" if progress < 100 else "\n"
+            msg = (
+                f"Exporting {self.data_type} for project {self.project_id}..."
+                + f"{progress}% (time remaining: {time_remaining_fmt})."
+            )
+            print(msg.ljust(100), end=end_char, flush=True)
 
-            # run progress check at 1s intervals so long as status == 'running' and progress < 100
-            if progress < 100:
-                t = threading.Timer(1.0, self._check_data_export_job_progress)
-                t.start()
-
-            return
-        elif status == "done":
-            self._on_data_export_job_done()
-        elif status == "error":
-            self._on_data_export_job_error()
+            # run progress check at 1s intervals so long as status == 'running'
+            t = threading.Timer(1.0, self._check_data_export_job_progress)
+            t.start()
 
     @retry(
         retry_on_exception=retry_on_http_error,
@@ -383,6 +447,10 @@ class ProjectDataManager:
             # annotations export will be single file
             annotations_fp = file_keys[0]
             return os.path.join(self.path, annotations_fp)
+        elif self.data_type == "model-outputs":
+            # model outputs export will be single file
+            model_outputs_fp = file_keys[0]
+            return os.path.join(self.path, model_outputs_fp)
 
     def _download_files(self, file_keys):
         """Downloads exported files.
@@ -529,7 +597,13 @@ class AnnotationsImportManager:
             self._on_job_error()
             return
 
-        if status == "running":
+        if status == "done":
+            self._on_job_done()
+
+        elif status == "error":
+            self._on_job_error()
+
+        elif status == "running":
             try:
                 progress = int(body["progress"])
             except (TypeError, ValueError):
@@ -540,32 +614,24 @@ class AnnotationsImportManager:
                 time_remaining = 0
 
             # print formatted progress info
-            if progress > 0 and progress <= 100 and time_remaining > 0:
-                if time_remaining > 45:
-                    time_remaining_fmt = (
-                        arrow.now().shift(seconds=time_remaining).humanize(only_distance=True)
-                    )
-                else:
-                    # arrow humanizes <= 45 to 'in seconds' or 'just now',
-                    # so we will opt to be explicit instead.
-                    time_remaining_fmt = f"in {time_remaining} seconds"
-                end_char = "\r" if progress < 100 else "\n"
-                msg = (
-                    f"Annotations import for project {self.project_id}..."
-                    + f"{progress}% (time remaining: {time_remaining_fmt})."
+            if time_remaining > 45:
+                time_remaining_fmt = (
+                    arrow.now().shift(seconds=time_remaining).humanize(only_distance=True)
                 )
-                print(msg.ljust(100), end=end_char, flush=True)
+            else:
+                # arrow humanizes <= 45 to 'in seconds' or 'just now',
+                # so we will opt to be explicit instead.
+                time_remaining_fmt = f"{time_remaining} seconds"
+            end_char = "\r" if progress < 100 else "\n"
+            msg = (
+                f"Annotations import for project {self.project_id}..."
+                + f"{progress}% (time remaining: {time_remaining_fmt})."
+            )
+            print(msg.ljust(100), end=end_char, flush=True)
 
-            # run progress check at 1s intervals so long as status == 'running' and progress < 100
-            if progress < 100:
-                t = threading.Timer(1.0, self._check_job_progress)
-                t.start()
-
-            return
-        elif status == "done":
-            self._on_job_done()
-        elif status == "error":
-            self._on_job_error()
+            # run progress check at 1s intervals so long as status == 'running'
+            t = threading.Timer(1.0, self._check_job_progress)
+            t.start()
 
     @retry(
         retry_on_exception=retry_on_http_error,
