@@ -4,8 +4,6 @@ import numpy as np
 import dicom2nifti
 import pydicom
 
-DEFAULT_WINDOW_WIDTH = 350
-DEFAULT_WINDOW_CENTER = 50
 DEFAULT_IMAGE_SIZE = (512.0, 512.0)
 
 
@@ -76,16 +74,15 @@ def remove_padding(array):
 def get_window_from_dicom(dicom_file):
     """
     Returns window width and window center values.
-    Defaults: width - 350, level - 50.
+    If no window width/level is provided or available, returns None.
     """
+    width, level = None, None
     if "WindowWidth" in dicom_file:
         width = dicom_file.WindowWidth
         if isinstance(width, pydicom.multival.MultiValue):
             width = int(width[0])
         else:
             width = int(width)
-    else:
-        width = DEFAULT_WINDOW_WIDTH
 
     if "WindowCenter" in dicom_file:
         level = dicom_file.WindowCenter
@@ -93,16 +90,16 @@ def get_window_from_dicom(dicom_file):
             level = int(level[0])
         else:
             level = int(level)
-    else:
-        level = DEFAULT_WINDOW_CENTER
     return width, level
 
 
 def window(array, width, level):
     """
     Applies windowing operation.
+    If window width/level is None, returns the array itself.
     """
-    array = np.clip(array, level - width // 2, level + width // 2)
+    if width is not None and level is not None:
+        array = np.clip(array, level - width // 2, level + width // 2)
     return array
 
 
@@ -139,7 +136,7 @@ def convert_dicom_to_nifti(dicom_files, tempdir):
     return sort_dicoms(dicom_files)
 
 
-def convert_dicom_to_8bit(dicom_file, imsize=None, width=None, level=None, remove_padding=False):
+def convert_dicom_to_8bit(dicom_file, imsize=None, width=None, level=None, keep_padding=True):
     """
     Given a DICOM file, window specifications, and image size,
     return the image as a Numpy array scaled to [0,255] of the specified size.
@@ -157,7 +154,7 @@ def convert_dicom_to_8bit(dicom_file, imsize=None, width=None, level=None, remov
     ):
         array = 255 - array
 
-    if remove_padding:
+    if not keep_padding:
         array = remove_padding(array)
 
     if imsize is not None:
